==> google_applovin_unity_ads-2.3.11.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAdManagerBannerAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import static android.view.ViewGroup.LayoutParams.MATCH_PARENT;
import static android.view.ViewGroup.LayoutParams.WRAP_CONTENT;

import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.view.ViewGroup.LayoutParams;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.btcpiyush.ads.google_applovin_unity_ads.FlutterAdSize;
import com.btcpiyush.ads.google_applovin_unity_ads.FlutterPlatformView;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.admanager.AdManagerAdView;
import com.google.android.gms.ads.admanager.AppEventListener;

import java.util.List;

import io.flutter.plugin.platform.PlatformView;
import io.flutter.util.Preconditions;

/**
 * Wrapper around {@link AdManagerAdView} for the Google Mobile
 * Ads Plugin.
 */
class FlutterAdManagerBannerAd extends FlutterAd implements FlutterAdLoadedListener {

    @NonNull
    protected final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final List<FlutterAdSize> sizes;
    @NonNull
    private final FlutterAdManagerAdRequest request;
    @NonNull
    private final BannerAdCreator bannerAdCreator;
    @Nullable
    protected AdManagerAdView adView;

    /**
     * Constructs a `FlutterAdManagerBannerAd`.
     *
     * <p>Call `load()` to instantiate the `AdView` and load the `AdRequest`. `getView()` will return
     * null only until `load` is called.
     */
    public FlutterAdManagerBannerAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull List<FlutterAdSize> sizes,
            @NonNull FlutterAdManagerAdRequest request,
            @NonNull BannerAdCreator bannerAdCreator) {
        super(adId);
        Preconditions.checkNotNull(manager);
        Preconditions.checkNotNull(adUnitId);
        Preconditions.checkNotNull(sizes);
        Preconditions.checkNotNull(request);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.sizes = sizes;
        this.request = request;
        this.bannerAdCreator = bannerAdCreator;
    }

    @Override
    void load() {
        adView = bannerAdCreator.createAdManagerAdView();
        if (this instanceof FluidAdManagerBannerAd) {
            adView.setLayoutParams(new LayoutParams(MATCH_PARENT, WRAP_CONTENT));
        }
        adView.setAdUnitId(adUnitId);
        adView.setAppEventListener(
                new AppEventListener() {
                    @Override
                    public void onAppEvent(String name, String data) {
                        manager.onAppEvent(adId, name, data);
                    }
                });

        final AdSize[] allSizes = new AdSize[sizes.size()];
        for (int i = 0; i < sizes.size(); i++) {
            allSizes[i] = sizes.get(i).getAdSize();
        }
        adView.setAdSizes(allSizes);
        adView.setAdListener(new FlutterBannerAdListener(adId, manager, this));
        adView.loadAd(request.asAdManagerAdRequest(adUnitId));
    }

    @Override
    public void onAdLoaded() {
        if (adView != null) {
            manager.onAdLoaded(adId, adView.getResponseInfo());
        }
    }

    @Nullable
    @Override
    PlatformView getPlatformView() {
        if (adView == null) {
            return null;
        }
        return new FlutterPlatformView(adView);
    }

    @Override
    void dispose() {
        if (adView != null) {
            adView.destroy();
            adView = null;
        }
    }

    @Nullable
    FlutterAdSize getAdSize() {
        if (adView == null || adView.getAdSize() == null) {
            return null;
        }
        return new FlutterAdSize(adView.getAdSize());
    }

    @Override
    public void onAdLoaded(@NonNull Drawable bitmap) {

    }

    @Override
    public void onAdLoadFailed() {

    }
}

==> google_applovin_unity_ads-2.3.18.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAdManagerBannerAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import static android.view.ViewGroup.LayoutParams.MATCH_PARENT;
import static android.view.ViewGroup.LayoutParams.WRAP_CONTENT;

import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.view.ViewGroup.LayoutParams;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.btcpiyush.ads.google_applovin_unity_ads.FlutterAdSize;
import com.btcpiyush.ads.google_applovin_unity_ads.FlutterPlatformView;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.admanager.AdManagerAdView;
import com.google.android.gms.ads.admanager.AppEventListener;

import java.util.List;

import io.flutter.plugin.platform.PlatformView;
import io.flutter.util.Preconditions;

/**
 * Wrapper around {@link AdManagerAdView} for the Google Mobile
 * Ads Plugin.
 */
class FlutterAdManagerBannerAd extends FlutterAd implements FlutterAdLoadedListener {

    @NonNull
    protected final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final List<FlutterAdSize> sizes;
    @NonNull
    private final FlutterAdManagerAdRequest request;
    @NonNull
    private final BannerAdCreator bannerAdCreator;
    @Nullable
    protected AdManagerAdView adView;

    /**
     * Constructs a `FlutterAdManagerBannerAd`.
     *
     * <p>Call `load()` to instantiate the `AdView` and load the `AdRequest`. `getView()` will return
     * null only until `load` is called.
     */
    public FlutterAdManagerBannerAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull List<FlutterAdSize> sizes,
            @NonNull FlutterAdManagerAdRequest request,
            @NonNull BannerAdCreator bannerAdCreator) {
        super(adId);
        Preconditions.checkNotNull(manager);
        Preconditions.checkNotNull(adUnitId);
        Preconditions.checkNotNull(sizes);
        Preconditions.checkNotNull(request);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.sizes = sizes;
        this.request = request;
        this.bannerAdCreator = bannerAdCreator;
    }

    @Override
    void load() {
        adView = bannerAdCreator.createAdManagerAdView();
        if (this instanceof FluidAdManagerBannerAd) {
            adView.setLayoutParams(new LayoutParams(MATCH_PARENT, WRAP_CONTENT));
        }
        adView.setAdUnitId(adUnitId);
        adView.setAppEventListener(
                new AppEventListener() {
                    @Override
                    public void onAppEvent(String name, String data) {
                        manager.onAppEvent(adId, name, data);
                    }
                });

        final AdSize[] allSizes = new AdSize[sizes.size()];
        for (int i = 0; i < sizes.size(); i++) {
            allSizes[i] = sizes.get(i).getAdSize();
        }
        adView.setAdSizes(allSizes);
        adView.setAdListener(new FlutterBannerAdListener(adId, manager, this));
        adView.loadAd(request.asAdManagerAdRequest(adUnitId));
    }

    @Override
    public void onAdLoaded() {
        if (adView != null) {
            manager.onAdLoaded(adId, adView.getResponseInfo());
        }
    }

    @Nullable
    @Override
    PlatformView getPlatformView() {
        if (adView == null) {
            return null;
        }
        return new FlutterPlatformView(adView);
    }

    @Override
    void dispose() {
        if (adView != null) {
            adView.destroy();
            adView = null;
        }
    }

    @Nullable
    FlutterAdSize getAdSize() {
        if (adView == null || adView.getAdSize() == null) {
            return null;
        }
        return new FlutterAdSize(adView.getAdSize());
    }

    @Override
    public void onAdLoaded(@NonNull Drawable bitmap) {}

    @Override
    public void onAdLoadFailed() {

    }
}
